
``rattail.db``
==============

.. automodule:: rattail.db

.. class:: Session

   SQLAlchemy session class for the Rattail database.

   See also :class:`sqlalchemy:sqlalchemy.orm.Session`.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   cache
   changes
   config
   model
   model.batch
   model.batch.handheld
   model.batch.inventory
   model.batch.labels
   model.batch.pricing
   model.batch.product
   model.batch.purchase
   model.batch.vendorcatalog
   model.core
   model.customers
   model.datasync
   model.labels
   model.org
   model.people
   model.products
   model.purchase
   model.stores
   model.users
   model.vendors
   util
